@@ -205,6 +205,17 @@ sampleTimeVaryingCovariates <- function(object, armID, needsDV) {
   return(retValue)
 }
 
+#_______________________________________________________________________________
+#----                           loadFromJSON                                ----
+#_______________________________________________________________________________
+
+setMethod("loadFromJSON", signature=c("fixed_covariate", "json_element"), definition=function(object, json) {
+  object@name <- json@data$name
+  object@distribution <- loadFromJSON(new(json@data$distribution$type), 
+                                      JSONElement(json@data$distribution))
+  return(object)
+})
+
 #_______________________________________________________________________________
 #----                              sample                                   ----
 #_______________________________________________________________________________
