@@ -42,6 +42,15 @@ DoseAdaptation <- function(formula, compartments=NULL) {
   return(new("dose_adaptation", formula=formula, compartments=as.character(compartments)))
 }
 
+#_______________________________________________________________________________
+#----                           loadFromJSON                                ----
+#_______________________________________________________________________________
+
+setMethod("loadFromJSON", signature=c("dose_adaptation", "json_element"), definition=function(object, json) {
+  object <- campsismod::mapJSONPropertiesToS4Slots(object, json)
+  return(object)
+})
+
 #_______________________________________________________________________________
 #----                                  show                                 ----
 #_______________________________________________________________________________
