@@ -30,5 +30,5 @@ Events <- function() {
 
 #' @rdname getTimes
 setMethod("getTimes", signature = c("events"), definition = function(object) {
-  return(object@list %>% purrr::map(.f=~.x@times) %>% purrr::flatten_dbl() %>% unique() %>% base::sort())
+  return(object@list %>% purrr::map(.f=~as.numeric(.x@times)) %>% purrr::flatten_dbl() %>% unique() %>% base::sort())
 })
\ No newline at end of file
