@@ -59,11 +59,3 @@ setupPlanSequential <- function() {
   future::plan(future::sequential)
 }
 
-#' Get scheduling mode for furrr (see argument 'scheduling' available in furrr options).
-#' 
-#' @param parallel use parallel computing with furrr, logical value
-#' @return 1 for parallel computing, 0 otherwise
-#' @keywords internal
-getFurrrScheduling <- function(parallel) {
-  return(ifelse(parallel, 1, 0))
-}
