@@ -24,6 +24,40 @@ simulate <- function(model, dataset, dest=NULL, events=NULL, scenarios=NULL, tab
 }
 
 setGeneric("simulate", function(model, dataset, dest=NULL, events=NULL, scenarios=NULL, tablefun=NULL, outvars=NULL, outfun=NULL, seed=NULL, replicates=1, dosing=FALSE, settings=NULL) {
+
+  if (is.null(settings)) {
+    settings <- Settings()
+  }
+  
+  # Loading from JSON
+  if (is.character(model) || is(model, "json_element")) {
+    model <- loadFromJSON(CampsisModel(), model)
+  }
+  if (is.character(dataset) || is(dataset, "json_element")) {
+    dataset <- loadFromJSON(Dataset(), dataset)
+  }
+  if (is.character(settings) || is(settings, "json_element")) {
+    settings <- loadFromJSON(Settings(), settings)
+  }
+  if (is.character(scenarios) || is(scenarios, "json_element")) {
+    scenarios <- loadFromJSON(Scenarios(), scenarios)
+  }
+  
+  # Propagate default settings
+  defaultSettings <- settings@default
+  if (is.null(dest)) {
+    dest <- defaultSettings@engine
+  }
+  if (is.null(seed)) {
+    seed <- defaultSettings@seed
+  }
+  if (is.null(outvars)) {
+    outvars <- defaultSettings@outvars
+  }
+  if (is.null(dosing)) {
+    dosing <- defaultSettings@dosing
+  }
+  
   dest <- preprocessDest(dest)
   events <- preprocessEvents(events)
   scenarios <- preprocessScenarios(scenarios)
@@ -32,10 +66,10 @@ setGeneric("simulate", function(model, dataset, dest=NULL, events=NULL, scenario
   outfun <- preprocessOutfun(outfun)
   seed <- getSeed(seed)
   replicates <- preprocessReplicates(replicates, model)
-  settings <- preprocessSettings(settings, dest)
   dosing <- preprocessDosing(dosing)
-  
-  standardGeneric("simulate")
+  settings <- preprocessSettings(settings, dest)
+
+  return(standardGeneric("simulate"))
 })
 
 #' Get simulation engine type.
@@ -155,7 +189,7 @@ simulateDelegateCore <- function(model, dataset, dest, events, tablefun, outvars
 
     # Calling events
     for (event in events@list) {
-      if (iteration@end %in% event@times) {
+      if (iteration@end %in% as.numeric(event@times)) {
         inits <- event@fun(inits)
       }
     }
@@ -204,6 +238,7 @@ processArmLabels <- function(campsis, arms) {
 #' @keywords internal
 #' @importFrom methods validObject
 #' @importFrom furrr future_imap_dfr
+#' @importFrom purrr imap_dfr
 simulateScenarios <- function(scenarios, model, dataset, dest, events,
                               tablefun, outvars, outfun, seed, replicates,
                               dosing, settings) {
@@ -213,7 +248,7 @@ simulateScenarios <- function(scenarios, model, dataset, dest, events,
       add(Scenario())
   }
   
-  outer <-  furrr::future_imap_dfr(.x=scenarios@list, .f=function(scenario, scenarioIndex) {
+  scenarioFun <- function(scenario, scenarioIndex) {
     model <- model %>% applyScenario(scenario)
     dataset <- dataset %>% applyScenario(scenario)
     
@@ -240,8 +275,8 @@ simulateScenarios <- function(scenarios, model, dataset, dest, events,
     }
     
     inner <- simulateDelegateCore(model=model, dataset=dataset, dest=dest, events=events,
-                                    tablefun=tablefun, outvars=outvars, outfun=outfun, seed=seed, replicates=replicates,
-                                    dosing=dosing, settings=settings)
+                                  tablefun=tablefun, outvars=outvars, outfun=outfun, seed=seed, replicates=replicates,
+                                  dosing=dosing, settings=settings)
     
     # Apply potential output function
     inner <- inner %>% applyOutfun(outfun=outfun, level="scenario", scenario=scenario@name)
@@ -250,9 +285,18 @@ simulateScenarios <- function(scenarios, model, dataset, dest, events,
     if (!emptyScenarios) {
       inner <- inner %>% dplyr::mutate(SCENARIO=scenario@name)
     }
-
+    
     return(inner)
-  }, .options=furrr::furrr_options(seed=NULL, scheduling=getFurrrScheduling(settings@hardware@scenario_parallel)))
+  }
+  
+  # Use 'future' only when required
+  mapFun <- if (settings@hardware@scenario_parallel && settings@hardware@cpu > 1) {
+    function(.x) {furrr::future_imap_dfr(.x=.x, .f=scenarioFun, .options=furrr::furrr_options(seed=NULL))}
+  } else {
+    function(.x) {purrr::imap_dfr(.x=.x, .f=scenarioFun)}
+  }
+  
+  outer <-  scenarios@list %>% mapFun()
   
   # Label arms (ARM column)
   if (is(dataset, "dataset")) {
@@ -268,6 +312,7 @@ simulateScenarios <- function(scenarios, model, dataset, dest, events,
 #' @return a data frame with the results
 #' @keywords internal
 #' @importFrom furrr furrr_options future_imap_dfr
+#' @importFrom purrr imap_dfr
 #' @importFrom progressr progressor
 #' @importFrom dplyr all_of mutate
 #' @importFrom stats setNames
@@ -306,19 +351,26 @@ simulateDelegate <- function(model, dataset, dest, events, scenarios, tablefun,
   seqReplicates <- seq_len(replicates)
   seqReplicates <- as.list(seqReplicates) %>%
     stats::setNames(seqReplicates) # Names are added for furrr (added automatically to the output with .id="replicate")
-  
-  allRep <- seqReplicates %>% furrr::future_map_dfr(.f=function(replicate) {
+
+  repFun <- function(replicate) {
     # Export model for each replicate
     model_ <- replicatedModel %>%
       campsismod::export(dest=CampsisModel(), index=replicate)
     
+    # Disable variabilities ('IIV', 'RUV', etc.)
+    disabledVariabilities <- settings@default@disabled_variabilities
+    if (length(disabledVariabilities) > 0) {
+      model_ <- model_ %>%
+        disable(disabledVariabilities)
+    }
+    
     # Update replicate counter
     settings@internal@progress <- settings@internal@progress %>% updateReplicate(replicate)
     retValue <- tryCatch(
       expr={
         inner <- simulateScenarios(scenarios=scenarios, model=model_, dataset=dataset, dest=dest, events=events,
-                                     tablefun=tablefun, outvars=outvars, outfun=outfun, seed=seed, replicates=replicates,
-                                     dosing=dosing, settings=settings)
+                                   tablefun=tablefun, outvars=outvars, outfun=outfun, seed=seed, replicates=replicates,
+                                   dosing=dosing, settings=settings)
         # Apply potential output function
         inner <- inner %>% applyOutfun(outfun=outfun, level="replicate", replicate=replicate) 
       },
@@ -333,7 +385,15 @@ simulateDelegate <- function(model, dataset, dest, events, scenarios, tablefun,
       }
     )
     return(retValue)
-  }, .id="replicate", .options=furrr::furrr_options(seed=NULL, scheduling=getFurrrScheduling(settings@hardware@replicate_parallel)))
+  }
+  
+  mapFun <- if (settings@hardware@replicate_parallel && settings@hardware@cpu > 1) {
+    function(.x) {furrr::future_map_dfr(.x=.x, .f=repFun, .id="replicate", .options=furrr::furrr_options(seed=NULL))}
+  } else {
+    function(.x) {purrr::map_dfr(.x=.x, .f=repFun, .id="replicate")}
+  }
+  
+  allRep <- seqReplicates %>% mapFun()
   
   # Remove 'replicate' column if only 1 replicate
   if (replicates==1) {
@@ -428,6 +488,9 @@ processSimulateArguments <- function(model, dataset, dest, outvars, dosing, sett
   if (iteration@index > 1) {
     model <- removeInitialConditions(model)
   }
+  
+  # Compartment names
+  cmtNames <- model@compartments@list %>% purrr::map_chr(~.x %>% toString())
 
   # Export to RxODE / rxode2
   if (is(dest, "rxode_engine")) {
@@ -450,6 +513,7 @@ processSimulateArguments <- function(model, dataset, dest, outvars, dosing, sett
     
     # Extra care to additional outputs which need to be explicitly declared with mrgsolve 
     outvars_ <- outvars[!(outvars %in% dropOthers())]
+    outvars_ <- outvars_[!outvars_ %in% cmtNames] # Exclude compartment names
     outvars_ <- unique(c(outvars_, "ARM", "EVENT_RELATED"))
     if (dosing) {
       # These variables are not output by default in mrgsolve when dosing is TRUE
@@ -470,9 +534,6 @@ processSimulateArguments <- function(model, dataset, dest, outvars, dosing, sett
     return(subdataset)
   })
 
-  # Compartment names
-  cmtNames <- model@compartments@list %>% purrr::map_chr(~.x %>% toString())
-  
   return(list(declare=declare, engineModel=engineModel, subdatasets=subdatasets,
               dropOthers=dropOthers, iteration=iteration, cmtNames=cmtNames))
 }
@@ -518,6 +579,7 @@ reorderColumns <- function(results, dosing) {
 }
 
 #' @importFrom furrr future_imap_dfr furrr_options
+#' @importFrom purrr imap_dfr
 #' @rdname simulate
 setMethod("simulate", signature=c("campsis_model", "tbl_df", "rxode_engine", "events", "scenarios", "function", "character", "output_function", "integer", "integer", "logical", "simulation_settings"),
           definition=function(model, dataset, dest, events, scenarios, tablefun, outvars, outfun, seed, replicates, dosing, settings) {
@@ -527,7 +589,7 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "rxode_engine", "ev
   summary <- settings@internal@dataset_summary
   
   # Retrieve simulation config
-  config <- processSimulateArguments(model=model, dataset=dataset, dest=dest, outvars=outvars, settings=settings)
+  config <- processSimulateArguments(model=model, dataset=dataset, dest=dest, outvars=outvars, dosing=dosing, settings=settings)
   progress <- settings@internal@progress
   progress@slices <- config$subdatasets %>% length()
 
@@ -567,10 +629,11 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "rxode_engine", "ev
   # Make sure to remove the list of sub-datasets from 'config' (see #166)
   subdatasets <- config$subdatasets
   config$subdatasets <- NULL
-
-  results <- furrr::future_imap_dfr(.x=subdatasets, .f=function(subdataset, index) {
+  
+  # This function will be called for each slice
+  sliceFunRxode <- function(subdataset, index) {
     inits <- getInitialConditions(subdataset, iteration=config$iteration, cmtNames=config$cmtNames)
-
+    
     # Launch simulation with RxODE
     if (dest@rxode2) {
       tmp <- rxode2::rxSolve(object=mod, params=params, omega=omega, sigma=sigma, events=subdataset, returnType="tibble",
@@ -603,7 +666,16 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "rxode_engine", "ev
     }
     
     return(processDropOthers(tmp, outvars=outvars, dropOthers=config$dropOthers))
-  }, .options=furrr::furrr_options(seed=TRUE, scheduling=getFurrrScheduling(settings@hardware@slice_parallel)))
+  }
+  
+  # Use 'future' only when required
+  mapFun <- if (settings@hardware@slice_parallel && settings@hardware@cpu > 1) {
+    function(.x) {furrr::future_imap_dfr(.x=.x, .f=sliceFunRxode, .options=furrr::furrr_options(seed=TRUE))}
+  } else {
+    function(.x) {purrr::imap_dfr(.x=.x, .f=sliceFunRxode)}
+  }
+
+  results <- subdatasets %>% mapFun()
   
   # Tick progress
   if (!tick_slice) {
@@ -615,6 +687,7 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "rxode_engine", "ev
 })
 
 #' @importFrom furrr future_imap_dfr furrr_options
+#' @importFrom purrr imap_dfr
 #' @importFrom digest sha1
 #' @rdname simulate
 setMethod("simulate", signature=c("campsis_model", "tbl_df", "mrgsolve_engine", "events", "scenarios", "function", "character", "output_function", "integer", "integer", "logical", "simulation_settings"),
@@ -660,10 +733,11 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "mrgsolve_engine",
   if (nrow(sigma) > 0) {
     mod <- mod %>% mrgsolve::update(sigma=sigma)
   }
-
-  results <-  furrr::future_imap_dfr(.x=subdatasets, .f=function(subdataset, index) {
+  
+  # This function will be called for each slice
+  sliceFunMrgsolve <- function(subdataset, index) {
     inits <- getInitialConditions(subdataset, iteration=config$iteration, cmtNames=config$cmtNames)
-
+    
     # Update init vector (see mrgsolve script: 'update.R')
     if (!is.null(inits)) {
       mod <- mod %>% mrgsolve::update(init=inits)
@@ -672,15 +746,24 @@ setMethod("simulate", signature=c("campsis_model", "tbl_df", "mrgsolve_engine",
     # Launch simulation with mrgsolve
     # Observation only set to TRUE to align results with RxODE
     tmp <- mod %>% mrgsolve::data_set(data=subdataset) %>% mrgsolve::mrgsim(obsonly=!dosing, output="df", nocb=nocb) %>% tibble::as_tibble()
-
+    
     # Tick progress
     if (tick_slice) {
       progress <- progress %>% updateSlice(index)
       progress <- progress %>% tick(tick_slice=tick_slice)
     }
-
+    
     return(processDropOthers(tmp, outvars=outvars, dropOthers=config$dropOthers))
-  }, .options=furrr::furrr_options(seed=TRUE, scheduling=getFurrrScheduling(settings@hardware@slice_parallel)))
+  }
+  
+  # Use 'future' only when required
+  mapFun <- if (settings@hardware@slice_parallel && settings@hardware@cpu > 1) {
+    function(.x) {furrr::future_imap_dfr(.x=.x, .f=sliceFunMrgsolve, .options=furrr::furrr_options(seed=TRUE))}
+  } else {
+    function(.x) {purrr::imap_dfr(.x=.x, .f=sliceFunMrgsolve)}
+  }
+
+  results <-  subdatasets %>% mapFun()
   
   # Tick progress
   if (!tick_slice) {
